pub struct ChargerProxy { /* private fields */ }Implementations
Sourceimpl ChargerProxy
impl ChargerProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.hardware.power.charger/Charger.
Sourcepub fn take_event_stream(&self) -> ChargerEventStream
pub fn take_event_stream(&self) -> ChargerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn get_spec(
&self,
) -> QueryResponseFut<ChargerGetSpecResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn get_spec( &self, ) -> QueryResponseFut<ChargerGetSpecResult, DefaultFuchsiaResourceDialect> ⓘ
Returns static hardware characteristics of the charger.
Sourcepub fn get_status(
&self,
) -> QueryResponseFut<ChargerGetStatusResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn get_status( &self, ) -> QueryResponseFut<ChargerGetStatusResult, DefaultFuchsiaResourceDialect> ⓘ
Returns the current dynamic status of the charger immediately.
Sourcepub fn set_charging_enabled(
&self,
enabled: bool,
) -> QueryResponseFut<ChargerSetChargingEnabledResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn set_charging_enabled( &self, enabled: bool, ) -> QueryResponseFut<ChargerSetChargingEnabledResult, DefaultFuchsiaResourceDialect> ⓘ
Control methods.
Errors:
NOT_SUPPORTED: If the hardware does not support enabling/disabling charging.INTERNAL: If an unexpected error occurred.
Sourcepub fn watch(
&self,
interest: &Status,
wake_on: &Status,
lease: Option<EventPair>,
) -> QueryResponseFut<ChargerWatchResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn watch( &self, interest: &Status, wake_on: &Status, lease: Option<EventPair>, ) -> QueryResponseFut<ChargerWatchResult, DefaultFuchsiaResourceDialect> ⓘ
Change notification for charger state using a “hanging-get” pattern.
Follows the same semantics and power management rules as
[fuchsia.hardware.power.source/Source.Watch].
Errors
ALREADY_BOUNDifWatchis called before the previous call completes.