pub struct ChargerWatchRequest {
pub interest: Status,
pub wake_on: Status,
pub lease: Option<EventPair>,
}Fields
interest: Statuswake_on: Statuslease: Option<EventPair>Trait Implementations
Sourceimpl Debug for ChargerWatchRequest
impl Debug for ChargerWatchRequest
Sourceimpl Decode<ChargerWatchRequest, DefaultFuchsiaResourceDialect> for ChargerWatchRequest
impl Decode<ChargerWatchRequest, DefaultFuchsiaResourceDialect> for ChargerWatchRequest
Sourceimpl<T0: Encode<Status, DefaultFuchsiaResourceDialect>, T1: Encode<Status, DefaultFuchsiaResourceDialect>, T2: Encode<Optional<HandleType<EventPair, { _ }, 16387>>, DefaultFuchsiaResourceDialect>> Encode<ChargerWatchRequest, DefaultFuchsiaResourceDialect> for (T0, T1, T2)
impl<T0: Encode<Status, DefaultFuchsiaResourceDialect>, T1: Encode<Status, DefaultFuchsiaResourceDialect>, T2: Encode<Optional<HandleType<EventPair, { _ }, 16387>>, DefaultFuchsiaResourceDialect>> Encode<ChargerWatchRequest, DefaultFuchsiaResourceDialect> for (T0, T1, T2)
Sourceimpl PartialEq for ChargerWatchRequest
impl PartialEq for ChargerWatchRequest
Sourceimpl ResourceTypeMarker for ChargerWatchRequest
impl ResourceTypeMarker for ChargerWatchRequest
Sourcetype Borrowed<'a> = &'a mut ChargerWatchRequest
type Borrowed<'a> = &'a mut ChargerWatchRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for ChargerWatchRequest
impl StructuralPartialEq for ChargerWatchRequest
Sourceimpl TypeMarker for ChargerWatchRequest
impl TypeMarker for ChargerWatchRequest
Sourcetype Owned = ChargerWatchRequest
type Owned = ChargerWatchRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for ChargerWatchRequest
impl RefUnwindSafe for ChargerWatchRequest
impl Send for ChargerWatchRequest
impl Sync for ChargerWatchRequest
impl Unpin for ChargerWatchRequest
impl UnsafeUnpin for ChargerWatchRequest
impl UnwindSafe for ChargerWatchRequest