pub struct ChargerWatchResponse {
pub status: Status,
pub wake_lease: Option<EventPair>,
}Fields
status: Statuswake_lease: Option<EventPair>Trait Implementations
Sourceimpl Debug for ChargerWatchResponse
impl Debug for ChargerWatchResponse
Sourceimpl Decode<ChargerWatchResponse, DefaultFuchsiaResourceDialect> for ChargerWatchResponse
impl Decode<ChargerWatchResponse, DefaultFuchsiaResourceDialect> for ChargerWatchResponse
Sourceimpl Encode<ChargerWatchResponse, DefaultFuchsiaResourceDialect> for &mut ChargerWatchResponse
impl Encode<ChargerWatchResponse, DefaultFuchsiaResourceDialect> for &mut ChargerWatchResponse
Sourceimpl<T0: Encode<Status, DefaultFuchsiaResourceDialect>, T1: Encode<Optional<HandleType<EventPair, { _ }, 16387>>, DefaultFuchsiaResourceDialect>> Encode<ChargerWatchResponse, DefaultFuchsiaResourceDialect> for (T0, T1)
impl<T0: Encode<Status, DefaultFuchsiaResourceDialect>, T1: Encode<Optional<HandleType<EventPair, { _ }, 16387>>, DefaultFuchsiaResourceDialect>> Encode<ChargerWatchResponse, DefaultFuchsiaResourceDialect> for (T0, T1)
Sourceimpl PartialEq for ChargerWatchResponse
impl PartialEq for ChargerWatchResponse
Sourceimpl ResourceTypeMarker for ChargerWatchResponse
impl ResourceTypeMarker for ChargerWatchResponse
Sourcetype Borrowed<'a> = &'a mut ChargerWatchResponse
type Borrowed<'a> = &'a mut ChargerWatchResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for ChargerWatchResponse
impl StructuralPartialEq for ChargerWatchResponse
Sourceimpl TypeMarker for ChargerWatchResponse
impl TypeMarker for ChargerWatchResponse
Sourcetype Owned = ChargerWatchResponse
type Owned = ChargerWatchResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for ChargerWatchResponse
impl RefUnwindSafe for ChargerWatchResponse
impl Send for ChargerWatchResponse
impl Sync for ChargerWatchResponse
impl Unpin for ChargerWatchResponse
impl UnsafeUnpin for ChargerWatchResponse
impl UnwindSafe for ChargerWatchResponse